Enum memtable_core::exts::prelude::Cell11 [−][src]
pub enum Cell11<A, B, C, D, E, F, G, H, I, J, K> {
A(A),
B(B),
C(C),
D(D),
E(E),
F(F),
G(G),
H(H),
I(I),
J(J),
K(K),
}Variants
Implementations
This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.Trait Implementations
impl<'de, A, B, C, D, E, F, G, H, I, J, K> Deserialize<'de> for Cell11<A, B, C, D, E, F, G, H, I, J, K> where
A: Deserialize<'de>,
B: Deserialize<'de>,
C: Deserialize<'de>,
D: Deserialize<'de>,
E: Deserialize<'de>,
F: Deserialize<'de>,
G: Deserialize<'de>,
H: Deserialize<'de>,
I: Deserialize<'de>,
J: Deserialize<'de>,
K: Deserialize<'de>, This is supported on cell only.
impl<'de, A, B, C, D, E, F, G, H, I, J, K> Deserialize<'de> for Cell11<A, B, C, D, E, F, G, H, I, J, K> where
A: Deserialize<'de>,
B: Deserialize<'de>,
C: Deserialize<'de>,
D: Deserialize<'de>,
E: Deserialize<'de>,
F: Deserialize<'de>,
G: Deserialize<'de>,
H: Deserialize<'de>,
I: Deserialize<'de>,
J: Deserialize<'de>,
K: Deserialize<'de>, This is supported on
cell only.fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error> where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error> where
__D: Deserializer<'de>, Deserialize this value from the given Serde deserializer. Read more
impl<A: PartialOrd, B: PartialOrd, C: PartialOrd, D: PartialOrd, E: PartialOrd, F: PartialOrd, G: PartialOrd, H: PartialOrd, I: PartialOrd, J: PartialOrd, K: PartialOrd> PartialOrd<Cell11<A, B, C, D, E, F, G, H, I, J, K>> for Cell11<A, B, C, D, E, F, G, H, I, J, K>This is supported on cell only.
impl<A: PartialOrd, B: PartialOrd, C: PartialOrd, D: PartialOrd, E: PartialOrd, F: PartialOrd, G: PartialOrd, H: PartialOrd, I: PartialOrd, J: PartialOrd, K: PartialOrd> PartialOrd<Cell11<A, B, C, D, E, F, G, H, I, J, K>> for Cell11<A, B, C, D, E, F, G, H, I, J, K>This is supported on
cell only.This method returns an ordering between self and other values if one exists. Read more
This method tests less than (for self and other) and is used by the < operator. Read more
This method tests less than or equal to (for self and other) and is used by the <=
operator. Read more
This method tests greater than (for self and other) and is used by the > operator. Read more
impl<A: Copy, B: Copy, C: Copy, D: Copy, E: Copy, F: Copy, G: Copy, H: Copy, I: Copy, J: Copy, K: Copy> Copy for Cell11<A, B, C, D, E, F, G, H, I, J, K>This is supported on
cell only.impl<A: Eq, B: Eq, C: Eq, D: Eq, E: Eq, F: Eq, G: Eq, H: Eq, I: Eq, J: Eq, K: Eq> Eq for Cell11<A, B, C, D, E, F, G, H, I, J, K>This is supported on
cell only.impl<A, B, C, D, E, F, G, H, I, J, K> StructuralEq for Cell11<A, B, C, D, E, F, G, H, I, J, K>This is supported on
cell only.impl<A, B, C, D, E, F, G, H, I, J, K> StructuralPartialEq for Cell11<A, B, C, D, E, F, G, H, I, J, K>This is supported on
cell only.Auto Trait Implementations
impl<A, B, C, D, E, F, G, H, I, J, K> RefUnwindSafe for Cell11<A, B, C, D, E, F, G, H, I, J, K> where
A: RefUnwindSafe,
B: RefUnwindSafe,
C: RefUnwindSafe,
D: RefUnwindSafe,
E: RefUnwindSafe,
F: RefUnwindSafe,
G: RefUnwindSafe,
H: RefUnwindSafe,
I: RefUnwindSafe,
J: RefUnwindSafe,
K: RefUnwindSafe, impl<A, B, C, D, E, F, G, H, I, J, K> Send for Cell11<A, B, C, D, E, F, G, H, I, J, K> where
A: Send,
B: Send,
C: Send,
D: Send,
E: Send,
F: Send,
G: Send,
H: Send,
I: Send,
J: Send,
K: Send, impl<A, B, C, D, E, F, G, H, I, J, K> Sync for Cell11<A, B, C, D, E, F, G, H, I, J, K> where
A: Sync,
B: Sync,
C: Sync,
D: Sync,
E: Sync,
F: Sync,
G: Sync,
H: Sync,
I: Sync,
J: Sync,
K: Sync, impl<A, B, C, D, E, F, G, H, I, J, K> Unpin for Cell11<A, B, C, D, E, F, G, H, I, J, K> where
A: Unpin,
B: Unpin,
C: Unpin,
D: Unpin,
E: Unpin,
F: Unpin,
G: Unpin,
H: Unpin,
I: Unpin,
J: Unpin,
K: Unpin, impl<A, B, C, D, E, F, G, H, I, J, K> UnwindSafe for Cell11<A, B, C, D, E, F, G, H, I, J, K> where
A: UnwindSafe,
B: UnwindSafe,
C: UnwindSafe,
D: UnwindSafe,
E: UnwindSafe,
F: UnwindSafe,
G: UnwindSafe,
H: UnwindSafe,
I: UnwindSafe,
J: UnwindSafe,
K: UnwindSafe, Blanket Implementations
Mutably borrows from an owned value. Read more