Enum memtable_core::exts::prelude::Cell12 [−][src]
pub enum Cell12<A, B, C, D, E, F, G, H, I, J, K, L> {
A(A),
B(B),
C(C),
D(D),
E(E),
F(F),
G(G),
H(H),
I(I),
J(J),
K(K),
L(L),
}Variants
Implementations
This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.Trait Implementations
impl<'de, A, B, C, D, E, F, G, H, I, J, K, L> Deserialize<'de> for Cell12<A, B, C, D, E, F, G, H, I, J, K, L> where
A: Deserialize<'de>,
B: Deserialize<'de>,
C: Deserialize<'de>,
D: Deserialize<'de>,
E: Deserialize<'de>,
F: Deserialize<'de>,
G: Deserialize<'de>,
H: Deserialize<'de>,
I: Deserialize<'de>,
J: Deserialize<'de>,
K: Deserialize<'de>,
L: Deserialize<'de>, This is supported on cell only.
impl<'de, A, B, C, D, E, F, G, H, I, J, K, L> Deserialize<'de> for Cell12<A, B, C, D, E, F, G, H, I, J, K, L> where
A: Deserialize<'de>,
B: Deserialize<'de>,
C: Deserialize<'de>,
D: Deserialize<'de>,
E: Deserialize<'de>,
F: Deserialize<'de>,
G: Deserialize<'de>,
H: Deserialize<'de>,
I: Deserialize<'de>,
J: Deserialize<'de>,
K: Deserialize<'de>,
L: Deserialize<'de>, This is supported on
cell only.fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error> where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error> where
__D: Deserializer<'de>, Deserialize this value from the given Serde deserializer. Read more
impl<A: PartialEq, B: PartialEq, C: PartialEq, D: PartialEq, E: PartialEq, F: PartialEq, G: PartialEq, H: PartialEq, I: PartialEq, J: PartialEq, K: PartialEq, L: PartialEq> PartialEq<Cell12<A, B, C, D, E, F, G, H, I, J, K, L>> for Cell12<A, B, C, D, E, F, G, H, I, J, K, L>This is supported on cell only.
impl<A: PartialEq, B: PartialEq, C: PartialEq, D: PartialEq, E: PartialEq, F: PartialEq, G: PartialEq, H: PartialEq, I: PartialEq, J: PartialEq, K: PartialEq, L: PartialEq> PartialEq<Cell12<A, B, C, D, E, F, G, H, I, J, K, L>> for Cell12<A, B, C, D, E, F, G, H, I, J, K, L>This is supported on
cell only.impl<A: PartialOrd, B: PartialOrd, C: PartialOrd, D: PartialOrd, E: PartialOrd, F: PartialOrd, G: PartialOrd, H: PartialOrd, I: PartialOrd, J: PartialOrd, K: PartialOrd, L: PartialOrd> PartialOrd<Cell12<A, B, C, D, E, F, G, H, I, J, K, L>> for Cell12<A, B, C, D, E, F, G, H, I, J, K, L>This is supported on cell only.
impl<A: PartialOrd, B: PartialOrd, C: PartialOrd, D: PartialOrd, E: PartialOrd, F: PartialOrd, G: PartialOrd, H: PartialOrd, I: PartialOrd, J: PartialOrd, K: PartialOrd, L: PartialOrd> PartialOrd<Cell12<A, B, C, D, E, F, G, H, I, J, K, L>> for Cell12<A, B, C, D, E, F, G, H, I, J, K, L>This is supported on
cell only.This method returns an ordering between self and other values if one exists. Read more
This method tests less than (for self and other) and is used by the < operator. Read more
This method tests less than or equal to (for self and other) and is used by the <=
operator. Read more
This method tests greater than (for self and other) and is used by the > operator. Read more
impl<A, B, C, D, E, F, G, H, I, J, K, L> Serialize for Cell12<A, B, C, D, E, F, G, H, I, J, K, L> where
A: Serialize,
B: Serialize,
C: Serialize,
D: Serialize,
E: Serialize,
F: Serialize,
G: Serialize,
H: Serialize,
I: Serialize,
J: Serialize,
K: Serialize,
L: Serialize, This is supported on cell only.
impl<A, B, C, D, E, F, G, H, I, J, K, L> Serialize for Cell12<A, B, C, D, E, F, G, H, I, J, K, L> where
A: Serialize,
B: Serialize,
C: Serialize,
D: Serialize,
E: Serialize,
F: Serialize,
G: Serialize,
H: Serialize,
I: Serialize,
J: Serialize,
K: Serialize,
L: Serialize, This is supported on
cell only.impl<A: Copy, B: Copy, C: Copy, D: Copy, E: Copy, F: Copy, G: Copy, H: Copy, I: Copy, J: Copy, K: Copy, L: Copy> Copy for Cell12<A, B, C, D, E, F, G, H, I, J, K, L>This is supported on
cell only.impl<A: Eq, B: Eq, C: Eq, D: Eq, E: Eq, F: Eq, G: Eq, H: Eq, I: Eq, J: Eq, K: Eq, L: Eq> Eq for Cell12<A, B, C, D, E, F, G, H, I, J, K, L>This is supported on
cell only.impl<A, B, C, D, E, F, G, H, I, J, K, L> StructuralEq for Cell12<A, B, C, D, E, F, G, H, I, J, K, L>This is supported on
cell only.impl<A, B, C, D, E, F, G, H, I, J, K, L> StructuralPartialEq for Cell12<A, B, C, D, E, F, G, H, I, J, K, L>This is supported on
cell only.Auto Trait Implementations
impl<A, B, C, D, E, F, G, H, I, J, K, L> RefUnwindSafe for Cell12<A, B, C, D, E, F, G, H, I, J, K, L> where
A: RefUnwindSafe,
B: RefUnwindSafe,
C: RefUnwindSafe,
D: RefUnwindSafe,
E: RefUnwindSafe,
F: RefUnwindSafe,
G: RefUnwindSafe,
H: RefUnwindSafe,
I: RefUnwindSafe,
J: RefUnwindSafe,
K: RefUnwindSafe,
L: RefUnwindSafe, impl<A, B, C, D, E, F, G, H, I, J, K, L> Send for Cell12<A, B, C, D, E, F, G, H, I, J, K, L> where
A: Send,
B: Send,
C: Send,
D: Send,
E: Send,
F: Send,
G: Send,
H: Send,
I: Send,
J: Send,
K: Send,
L: Send, impl<A, B, C, D, E, F, G, H, I, J, K, L> Sync for Cell12<A, B, C, D, E, F, G, H, I, J, K, L> where
A: Sync,
B: Sync,
C: Sync,
D: Sync,
E: Sync,
F: Sync,
G: Sync,
H: Sync,
I: Sync,
J: Sync,
K: Sync,
L: Sync, impl<A, B, C, D, E, F, G, H, I, J, K, L> Unpin for Cell12<A, B, C, D, E, F, G, H, I, J, K, L> where
A: Unpin,
B: Unpin,
C: Unpin,
D: Unpin,
E: Unpin,
F: Unpin,
G: Unpin,
H: Unpin,
I: Unpin,
J: Unpin,
K: Unpin,
L: Unpin, impl<A, B, C, D, E, F, G, H, I, J, K, L> UnwindSafe for Cell12<A, B, C, D, E, F, G, H, I, J, K, L> where
A: UnwindSafe,
B: UnwindSafe,
C: UnwindSafe,
D: UnwindSafe,
E: UnwindSafe,
F: UnwindSafe,
G: UnwindSafe,
H: UnwindSafe,
I: UnwindSafe,
J: UnwindSafe,
K: UnwindSafe,
L: UnwindSafe, Blanket Implementations
Mutably borrows from an owned value. Read more