Enum memtable_core::exts::prelude::Cell14 [−][src]
pub enum Cell14<A, B, C, D, E, F, G, H, I, J, K, L, M, N> {
Show variants
A(A),
B(B),
C(C),
D(D),
E(E),
F(F),
G(G),
H(H),
I(I),
J(J),
K(K),
L(L),
M(M),
N(N),
}Variants
Implementations
This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.Trait Implementations
impl<'de, A, B, C, D, E, F, G, H, I, J, K, L, M, N> Deserialize<'de> for Cell14<A, B, C, D, E, F, G, H, I, J, K, L, M, N> where
A: Deserialize<'de>,
B: Deserialize<'de>,
C: Deserialize<'de>,
D: Deserialize<'de>,
E: Deserialize<'de>,
F: Deserialize<'de>,
G: Deserialize<'de>,
H: Deserialize<'de>,
I: Deserialize<'de>,
J: Deserialize<'de>,
K: Deserialize<'de>,
L: Deserialize<'de>,
M: Deserialize<'de>,
N: Deserialize<'de>, This is supported on cell only.
impl<'de, A, B, C, D, E, F, G, H, I, J, K, L, M, N> Deserialize<'de> for Cell14<A, B, C, D, E, F, G, H, I, J, K, L, M, N> where
A: Deserialize<'de>,
B: Deserialize<'de>,
C: Deserialize<'de>,
D: Deserialize<'de>,
E: Deserialize<'de>,
F: Deserialize<'de>,
G: Deserialize<'de>,
H: Deserialize<'de>,
I: Deserialize<'de>,
J: Deserialize<'de>,
K: Deserialize<'de>,
L: Deserialize<'de>,
M: Deserialize<'de>,
N: Deserialize<'de>, This is supported on
cell only.fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error> where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error> where
__D: Deserializer<'de>, Deserialize this value from the given Serde deserializer. Read more
impl<A: PartialEq, B: PartialEq, C: PartialEq, D: PartialEq, E: PartialEq, F: PartialEq, G: PartialEq, H: PartialEq, I: PartialEq, J: PartialEq, K: PartialEq, L: PartialEq, M: PartialEq, N: PartialEq> PartialEq<Cell14<A, B, C, D, E, F, G, H, I, J, K, L, M, N>> for Cell14<A, B, C, D, E, F, G, H, I, J, K, L, M, N>This is supported on cell only.
impl<A: PartialEq, B: PartialEq, C: PartialEq, D: PartialEq, E: PartialEq, F: PartialEq, G: PartialEq, H: PartialEq, I: PartialEq, J: PartialEq, K: PartialEq, L: PartialEq, M: PartialEq, N: PartialEq> PartialEq<Cell14<A, B, C, D, E, F, G, H, I, J, K, L, M, N>> for Cell14<A, B, C, D, E, F, G, H, I, J, K, L, M, N>This is supported on
cell only.impl<A: PartialOrd, B: PartialOrd, C: PartialOrd, D: PartialOrd, E: PartialOrd, F: PartialOrd, G: PartialOrd, H: PartialOrd, I: PartialOrd, J: PartialOrd, K: PartialOrd, L: PartialOrd, M: PartialOrd, N: PartialOrd> PartialOrd<Cell14<A, B, C, D, E, F, G, H, I, J, K, L, M, N>> for Cell14<A, B, C, D, E, F, G, H, I, J, K, L, M, N>This is supported on cell only.
impl<A: PartialOrd, B: PartialOrd, C: PartialOrd, D: PartialOrd, E: PartialOrd, F: PartialOrd, G: PartialOrd, H: PartialOrd, I: PartialOrd, J: PartialOrd, K: PartialOrd, L: PartialOrd, M: PartialOrd, N: PartialOrd> PartialOrd<Cell14<A, B, C, D, E, F, G, H, I, J, K, L, M, N>> for Cell14<A, B, C, D, E, F, G, H, I, J, K, L, M, N>This is supported on
cell only.fn partial_cmp(
&self,
other: &Cell14<A, B, C, D, E, F, G, H, I, J, K, L, M, N>
) -> Option<Ordering>
fn partial_cmp(
&self,
other: &Cell14<A, B, C, D, E, F, G, H, I, J, K, L, M, N>
) -> Option<Ordering>This method returns an ordering between self and other values if one exists. Read more
This method tests less than (for self and other) and is used by the < operator. Read more
This method tests less than or equal to (for self and other) and is used by the <=
operator. Read more
This method tests greater than (for self and other) and is used by the > operator. Read more
impl<A, B, C, D, E, F, G, H, I, J, K, L, M, N> Serialize for Cell14<A, B, C, D, E, F, G, H, I, J, K, L, M, N> where
A: Serialize,
B: Serialize,
C: Serialize,
D: Serialize,
E: Serialize,
F: Serialize,
G: Serialize,
H: Serialize,
I: Serialize,
J: Serialize,
K: Serialize,
L: Serialize,
M: Serialize,
N: Serialize, This is supported on cell only.
impl<A, B, C, D, E, F, G, H, I, J, K, L, M, N> Serialize for Cell14<A, B, C, D, E, F, G, H, I, J, K, L, M, N> where
A: Serialize,
B: Serialize,
C: Serialize,
D: Serialize,
E: Serialize,
F: Serialize,
G: Serialize,
H: Serialize,
I: Serialize,
J: Serialize,
K: Serialize,
L: Serialize,
M: Serialize,
N: Serialize, This is supported on
cell only.impl<A: Copy, B: Copy, C: Copy, D: Copy, E: Copy, F: Copy, G: Copy, H: Copy, I: Copy, J: Copy, K: Copy, L: Copy, M: Copy, N: Copy> Copy for Cell14<A, B, C, D, E, F, G, H, I, J, K, L, M, N>This is supported on
cell only.impl<A: Eq, B: Eq, C: Eq, D: Eq, E: Eq, F: Eq, G: Eq, H: Eq, I: Eq, J: Eq, K: Eq, L: Eq, M: Eq, N: Eq> Eq for Cell14<A, B, C, D, E, F, G, H, I, J, K, L, M, N>This is supported on
cell only.impl<A, B, C, D, E, F, G, H, I, J, K, L, M, N> StructuralEq for Cell14<A, B, C, D, E, F, G, H, I, J, K, L, M, N>This is supported on
cell only.impl<A, B, C, D, E, F, G, H, I, J, K, L, M, N> StructuralPartialEq for Cell14<A, B, C, D, E, F, G, H, I, J, K, L, M, N>This is supported on
cell only.Auto Trait Implementations
impl<A, B, C, D, E, F, G, H, I, J, K, L, M, N> RefUnwindSafe for Cell14<A, B, C, D, E, F, G, H, I, J, K, L, M, N> where
A: RefUnwindSafe,
B: RefUnwindSafe,
C: RefUnwindSafe,
D: RefUnwindSafe,
E: RefUnwindSafe,
F: RefUnwindSafe,
G: RefUnwindSafe,
H: RefUnwindSafe,
I: RefUnwindSafe,
J: RefUnwindSafe,
K: RefUnwindSafe,
L: RefUnwindSafe,
M: RefUnwindSafe,
N: RefUnwindSafe, impl<A, B, C, D, E, F, G, H, I, J, K, L, M, N> Send for Cell14<A, B, C, D, E, F, G, H, I, J, K, L, M, N> where
A: Send,
B: Send,
C: Send,
D: Send,
E: Send,
F: Send,
G: Send,
H: Send,
I: Send,
J: Send,
K: Send,
L: Send,
M: Send,
N: Send, impl<A, B, C, D, E, F, G, H, I, J, K, L, M, N> Sync for Cell14<A, B, C, D, E, F, G, H, I, J, K, L, M, N> where
A: Sync,
B: Sync,
C: Sync,
D: Sync,
E: Sync,
F: Sync,
G: Sync,
H: Sync,
I: Sync,
J: Sync,
K: Sync,
L: Sync,
M: Sync,
N: Sync, impl<A, B, C, D, E, F, G, H, I, J, K, L, M, N> Unpin for Cell14<A, B, C, D, E, F, G, H, I, J, K, L, M, N> where
A: Unpin,
B: Unpin,
C: Unpin,
D: Unpin,
E: Unpin,
F: Unpin,
G: Unpin,
H: Unpin,
I: Unpin,
J: Unpin,
K: Unpin,
L: Unpin,
M: Unpin,
N: Unpin, impl<A, B, C, D, E, F, G, H, I, J, K, L, M, N> UnwindSafe for Cell14<A, B, C, D, E, F, G, H, I, J, K, L, M, N> where
A: UnwindSafe,
B: UnwindSafe,
C: UnwindSafe,
D: UnwindSafe,
E: UnwindSafe,
F: UnwindSafe,
G: UnwindSafe,
H: UnwindSafe,
I: UnwindSafe,
J: UnwindSafe,
K: UnwindSafe,
L: UnwindSafe,
M: UnwindSafe,
N: UnwindSafe, Blanket Implementations
Mutably borrows from an owned value. Read more