Enum memtable_core::exts::prelude::Cell21 [−][src]
pub enum Cell21<A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P, Q, R, S, T, U> {
Show variants
A(A),
B(B),
C(C),
D(D),
E(E),
F(F),
G(G),
H(H),
I(I),
J(J),
K(K),
L(L),
M(M),
N(N),
O(O),
P(P),
Q(Q),
R(R),
S(S),
T(T),
U(U),
}Variants
Implementations
This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.Trait Implementations
impl<A: Clone, B: Clone, C: Clone, D: Clone, E: Clone, F: Clone, G: Clone, H: Clone, I: Clone, J: Clone, K: Clone, L: Clone, M: Clone, N: Clone, O: Clone, P: Clone, Q: Clone, R: Clone, S: Clone, T: Clone, U: Clone> Clone for Cell21<A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P, Q, R, S, T, U>This is supported on cell only.
impl<A: Clone, B: Clone, C: Clone, D: Clone, E: Clone, F: Clone, G: Clone, H: Clone, I: Clone, J: Clone, K: Clone, L: Clone, M: Clone, N: Clone, O: Clone, P: Clone, Q: Clone, R: Clone, S: Clone, T: Clone, U: Clone> Clone for Cell21<A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P, Q, R, S, T, U>This is supported on
cell only.impl<A: Debug, B: Debug, C: Debug, D: Debug, E: Debug, F: Debug, G: Debug, H: Debug, I: Debug, J: Debug, K: Debug, L: Debug, M: Debug, N: Debug, O: Debug, P: Debug, Q: Debug, R: Debug, S: Debug, T: Debug, U: Debug> Debug for Cell21<A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P, Q, R, S, T, U>This is supported on cell only.
impl<A: Debug, B: Debug, C: Debug, D: Debug, E: Debug, F: Debug, G: Debug, H: Debug, I: Debug, J: Debug, K: Debug, L: Debug, M: Debug, N: Debug, O: Debug, P: Debug, Q: Debug, R: Debug, S: Debug, T: Debug, U: Debug> Debug for Cell21<A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P, Q, R, S, T, U>This is supported on
cell only.impl<'de, A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P, Q, R, S, T, U> Deserialize<'de> for Cell21<A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P, Q, R, S, T, U> where
A: Deserialize<'de>,
B: Deserialize<'de>,
C: Deserialize<'de>,
D: Deserialize<'de>,
E: Deserialize<'de>,
F: Deserialize<'de>,
G: Deserialize<'de>,
H: Deserialize<'de>,
I: Deserialize<'de>,
J: Deserialize<'de>,
K: Deserialize<'de>,
L: Deserialize<'de>,
M: Deserialize<'de>,
N: Deserialize<'de>,
O: Deserialize<'de>,
P: Deserialize<'de>,
Q: Deserialize<'de>,
R: Deserialize<'de>,
S: Deserialize<'de>,
T: Deserialize<'de>,
U: Deserialize<'de>, This is supported on cell only.
impl<'de, A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P, Q, R, S, T, U> Deserialize<'de> for Cell21<A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P, Q, R, S, T, U> where
A: Deserialize<'de>,
B: Deserialize<'de>,
C: Deserialize<'de>,
D: Deserialize<'de>,
E: Deserialize<'de>,
F: Deserialize<'de>,
G: Deserialize<'de>,
H: Deserialize<'de>,
I: Deserialize<'de>,
J: Deserialize<'de>,
K: Deserialize<'de>,
L: Deserialize<'de>,
M: Deserialize<'de>,
N: Deserialize<'de>,
O: Deserialize<'de>,
P: Deserialize<'de>,
Q: Deserialize<'de>,
R: Deserialize<'de>,
S: Deserialize<'de>,
T: Deserialize<'de>,
U: Deserialize<'de>, This is supported on
cell only.fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error> where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error> where
__D: Deserializer<'de>, Deserialize this value from the given Serde deserializer. Read more
impl<A: Hash, B: Hash, C: Hash, D: Hash, E: Hash, F: Hash, G: Hash, H: Hash, I: Hash, J: Hash, K: Hash, L: Hash, M: Hash, N: Hash, O: Hash, P: Hash, Q: Hash, R: Hash, S: Hash, T: Hash, U: Hash> Hash for Cell21<A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P, Q, R, S, T, U>This is supported on cell only.
impl<A: Hash, B: Hash, C: Hash, D: Hash, E: Hash, F: Hash, G: Hash, H: Hash, I: Hash, J: Hash, K: Hash, L: Hash, M: Hash, N: Hash, O: Hash, P: Hash, Q: Hash, R: Hash, S: Hash, T: Hash, U: Hash> Hash for Cell21<A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P, Q, R, S, T, U>This is supported on
cell only.impl<A: PartialEq, B: PartialEq, C: PartialEq, D: PartialEq, E: PartialEq, F: PartialEq, G: PartialEq, H: PartialEq, I: PartialEq, J: PartialEq, K: PartialEq, L: PartialEq, M: PartialEq, N: PartialEq, O: PartialEq, P: PartialEq, Q: PartialEq, R: PartialEq, S: PartialEq, T: PartialEq, U: PartialEq> PartialEq<Cell21<A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P, Q, R, S, T, U>> for Cell21<A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P, Q, R, S, T, U>This is supported on cell only.
impl<A: PartialEq, B: PartialEq, C: PartialEq, D: PartialEq, E: PartialEq, F: PartialEq, G: PartialEq, H: PartialEq, I: PartialEq, J: PartialEq, K: PartialEq, L: PartialEq, M: PartialEq, N: PartialEq, O: PartialEq, P: PartialEq, Q: PartialEq, R: PartialEq, S: PartialEq, T: PartialEq, U: PartialEq> PartialEq<Cell21<A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P, Q, R, S, T, U>> for Cell21<A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P, Q, R, S, T, U>This is supported on
cell only.This method tests for self and other values to be equal, and is used
by ==. Read more
impl<A: PartialOrd, B: PartialOrd, C: PartialOrd, D: PartialOrd, E: PartialOrd, F: PartialOrd, G: PartialOrd, H: PartialOrd, I: PartialOrd, J: PartialOrd, K: PartialOrd, L: PartialOrd, M: PartialOrd, N: PartialOrd, O: PartialOrd, P: PartialOrd, Q: PartialOrd, R: PartialOrd, S: PartialOrd, T: PartialOrd, U: PartialOrd> PartialOrd<Cell21<A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P, Q, R, S, T, U>> for Cell21<A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P, Q, R, S, T, U>This is supported on cell only.
impl<A: PartialOrd, B: PartialOrd, C: PartialOrd, D: PartialOrd, E: PartialOrd, F: PartialOrd, G: PartialOrd, H: PartialOrd, I: PartialOrd, J: PartialOrd, K: PartialOrd, L: PartialOrd, M: PartialOrd, N: PartialOrd, O: PartialOrd, P: PartialOrd, Q: PartialOrd, R: PartialOrd, S: PartialOrd, T: PartialOrd, U: PartialOrd> PartialOrd<Cell21<A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P, Q, R, S, T, U>> for Cell21<A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P, Q, R, S, T, U>This is supported on
cell only.fn partial_cmp(
&self,
other: &Cell21<A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P, Q, R, S, T, U>
) -> Option<Ordering>
fn partial_cmp(
&self,
other: &Cell21<A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P, Q, R, S, T, U>
) -> Option<Ordering>This method returns an ordering between self and other values if one exists. Read more
This method tests less than (for self and other) and is used by the < operator. Read more
This method tests less than or equal to (for self and other) and is used by the <=
operator. Read more
This method tests greater than (for self and other) and is used by the > operator. Read more
impl<A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P, Q, R, S, T, U> Serialize for Cell21<A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P, Q, R, S, T, U> where
A: Serialize,
B: Serialize,
C: Serialize,
D: Serialize,
E: Serialize,
F: Serialize,
G: Serialize,
H: Serialize,
I: Serialize,
J: Serialize,
K: Serialize,
L: Serialize,
M: Serialize,
N: Serialize,
O: Serialize,
P: Serialize,
Q: Serialize,
R: Serialize,
S: Serialize,
T: Serialize,
U: Serialize, This is supported on cell only.
impl<A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P, Q, R, S, T, U> Serialize for Cell21<A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P, Q, R, S, T, U> where
A: Serialize,
B: Serialize,
C: Serialize,
D: Serialize,
E: Serialize,
F: Serialize,
G: Serialize,
H: Serialize,
I: Serialize,
J: Serialize,
K: Serialize,
L: Serialize,
M: Serialize,
N: Serialize,
O: Serialize,
P: Serialize,
Q: Serialize,
R: Serialize,
S: Serialize,
T: Serialize,
U: Serialize, This is supported on
cell only.impl<A: Copy, B: Copy, C: Copy, D: Copy, E: Copy, F: Copy, G: Copy, H: Copy, I: Copy, J: Copy, K: Copy, L: Copy, M: Copy, N: Copy, O: Copy, P: Copy, Q: Copy, R: Copy, S: Copy, T: Copy, U: Copy> Copy for Cell21<A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P, Q, R, S, T, U>This is supported on
cell only.impl<A: Eq, B: Eq, C: Eq, D: Eq, E: Eq, F: Eq, G: Eq, H: Eq, I: Eq, J: Eq, K: Eq, L: Eq, M: Eq, N: Eq, O: Eq, P: Eq, Q: Eq, R: Eq, S: Eq, T: Eq, U: Eq> Eq for Cell21<A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P, Q, R, S, T, U>This is supported on
cell only.impl<A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P, Q, R, S, T, U> StructuralEq for Cell21<A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P, Q, R, S, T, U>This is supported on
cell only.impl<A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P, Q, R, S, T, U> StructuralPartialEq for Cell21<A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P, Q, R, S, T, U>This is supported on
cell only.Auto Trait Implementations
impl<A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P, Q, R, S, T, U> RefUnwindSafe for Cell21<A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P, Q, R, S, T, U> where
A: RefUnwindSafe,
B: RefUnwindSafe,
C: RefUnwindSafe,
D: RefUnwindSafe,
E: RefUnwindSafe,
F: RefUnwindSafe,
G: RefUnwindSafe,
H: RefUnwindSafe,
I: RefUnwindSafe,
J: RefUnwindSafe,
K: RefUnwindSafe,
L: RefUnwindSafe,
M: RefUnwindSafe,
N: RefUnwindSafe,
O: RefUnwindSafe,
P: RefUnwindSafe,
Q: RefUnwindSafe,
R: RefUnwindSafe,
S: RefUnwindSafe,
T: RefUnwindSafe,
U: RefUnwindSafe, impl<A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P, Q, R, S, T, U> Send for Cell21<A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P, Q, R, S, T, U> where
A: Send,
B: Send,
C: Send,
D: Send,
E: Send,
F: Send,
G: Send,
H: Send,
I: Send,
J: Send,
K: Send,
L: Send,
M: Send,
N: Send,
O: Send,
P: Send,
Q: Send,
R: Send,
S: Send,
T: Send,
U: Send, impl<A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P, Q, R, S, T, U> Sync for Cell21<A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P, Q, R, S, T, U> where
A: Sync,
B: Sync,
C: Sync,
D: Sync,
E: Sync,
F: Sync,
G: Sync,
H: Sync,
I: Sync,
J: Sync,
K: Sync,
L: Sync,
M: Sync,
N: Sync,
O: Sync,
P: Sync,
Q: Sync,
R: Sync,
S: Sync,
T: Sync,
U: Sync, impl<A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P, Q, R, S, T, U> Unpin for Cell21<A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P, Q, R, S, T, U> where
A: Unpin,
B: Unpin,
C: Unpin,
D: Unpin,
E: Unpin,
F: Unpin,
G: Unpin,
H: Unpin,
I: Unpin,
J: Unpin,
K: Unpin,
L: Unpin,
M: Unpin,
N: Unpin,
O: Unpin,
P: Unpin,
Q: Unpin,
R: Unpin,
S: Unpin,
T: Unpin,
U: Unpin, impl<A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P, Q, R, S, T, U> UnwindSafe for Cell21<A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P, Q, R, S, T, U> where
A: UnwindSafe,
B: UnwindSafe,
C: UnwindSafe,
D: UnwindSafe,
E: UnwindSafe,
F: UnwindSafe,
G: UnwindSafe,
H: UnwindSafe,
I: UnwindSafe,
J: UnwindSafe,
K: UnwindSafe,
L: UnwindSafe,
M: UnwindSafe,
N: UnwindSafe,
O: UnwindSafe,
P: UnwindSafe,
Q: UnwindSafe,
R: UnwindSafe,
S: UnwindSafe,
T: UnwindSafe,
U: UnwindSafe, Blanket Implementations
Mutably borrows from an owned value. Read more