Enum memtable_core::exts::prelude::Cell3 [−][src]
pub enum Cell3<A, B, C> {
A(A),
B(B),
C(C),
}Variants
Implementations
This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.Trait Implementations
impl<'de, A, B, C> Deserialize<'de> for Cell3<A, B, C> where
A: Deserialize<'de>,
B: Deserialize<'de>,
C: Deserialize<'de>, This is supported on cell only.
impl<'de, A, B, C> Deserialize<'de> for Cell3<A, B, C> where
A: Deserialize<'de>,
B: Deserialize<'de>,
C: Deserialize<'de>, This is supported on
cell only.fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error> where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error> where
__D: Deserializer<'de>, Deserialize this value from the given Serde deserializer. Read more
impl<A: PartialOrd, B: PartialOrd, C: PartialOrd> PartialOrd<Cell3<A, B, C>> for Cell3<A, B, C>This is supported on cell only.
impl<A: PartialOrd, B: PartialOrd, C: PartialOrd> PartialOrd<Cell3<A, B, C>> for Cell3<A, B, C>This is supported on
cell only.This method returns an ordering between self and other values if one exists. Read more
This method tests less than (for self and other) and is used by the < operator. Read more
This method tests less than or equal to (for self and other) and is used by the <=
operator. Read more
This method tests greater than (for self and other) and is used by the > operator. Read more