Enum memtable_core::exts::prelude::Cell5 [−][src]
pub enum Cell5<A, B, C, D, E> {
A(A),
B(B),
C(C),
D(D),
E(E),
}Variants
Implementations
This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.Trait Implementations
impl<'de, A, B, C, D, E> Deserialize<'de> for Cell5<A, B, C, D, E> where
A: Deserialize<'de>,
B: Deserialize<'de>,
C: Deserialize<'de>,
D: Deserialize<'de>,
E: Deserialize<'de>, This is supported on cell only.
impl<'de, A, B, C, D, E> Deserialize<'de> for Cell5<A, B, C, D, E> where
A: Deserialize<'de>,
B: Deserialize<'de>,
C: Deserialize<'de>,
D: Deserialize<'de>,
E: Deserialize<'de>, This is supported on
cell only.fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error> where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error> where
__D: Deserializer<'de>, Deserialize this value from the given Serde deserializer. Read more
impl<A: PartialOrd, B: PartialOrd, C: PartialOrd, D: PartialOrd, E: PartialOrd> PartialOrd<Cell5<A, B, C, D, E>> for Cell5<A, B, C, D, E>This is supported on cell only.
impl<A: PartialOrd, B: PartialOrd, C: PartialOrd, D: PartialOrd, E: PartialOrd> PartialOrd<Cell5<A, B, C, D, E>> for Cell5<A, B, C, D, E>This is supported on
cell only.This method returns an ordering between self and other values if one exists. Read more
This method tests less than (for self and other) and is used by the < operator. Read more
This method tests less than or equal to (for self and other) and is used by the <=
operator. Read more
This method tests greater than (for self and other) and is used by the > operator. Read more
impl<A: Copy, B: Copy, C: Copy, D: Copy, E: Copy> Copy for Cell5<A, B, C, D, E>This is supported on
cell only.Auto Trait Implementations
impl<A, B, C, D, E> RefUnwindSafe for Cell5<A, B, C, D, E> where
A: RefUnwindSafe,
B: RefUnwindSafe,
C: RefUnwindSafe,
D: RefUnwindSafe,
E: RefUnwindSafe, impl<A, B, C, D, E> Send for Cell5<A, B, C, D, E> where
A: Send,
B: Send,
C: Send,
D: Send,
E: Send, impl<A, B, C, D, E> Sync for Cell5<A, B, C, D, E> where
A: Sync,
B: Sync,
C: Sync,
D: Sync,
E: Sync, impl<A, B, C, D, E> Unpin for Cell5<A, B, C, D, E> where
A: Unpin,
B: Unpin,
C: Unpin,
D: Unpin,
E: Unpin, impl<A, B, C, D, E> UnwindSafe for Cell5<A, B, C, D, E> where
A: UnwindSafe,
B: UnwindSafe,
C: UnwindSafe,
D: UnwindSafe,
E: UnwindSafe, Blanket Implementations
Mutably borrows from an owned value. Read more