Enum memtable_core::exts::prelude::Cell6 [−][src]
pub enum Cell6<A, B, C, D, E, F> {
A(A),
B(B),
C(C),
D(D),
E(E),
F(F),
}Variants
Implementations
This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.Trait Implementations
impl<'de, A, B, C, D, E, F> Deserialize<'de> for Cell6<A, B, C, D, E, F> where
A: Deserialize<'de>,
B: Deserialize<'de>,
C: Deserialize<'de>,
D: Deserialize<'de>,
E: Deserialize<'de>,
F: Deserialize<'de>, This is supported on cell only.
impl<'de, A, B, C, D, E, F> Deserialize<'de> for Cell6<A, B, C, D, E, F> where
A: Deserialize<'de>,
B: Deserialize<'de>,
C: Deserialize<'de>,
D: Deserialize<'de>,
E: Deserialize<'de>,
F: Deserialize<'de>, This is supported on
cell only.fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error> where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error> where
__D: Deserializer<'de>, Deserialize this value from the given Serde deserializer. Read more
impl<A: PartialOrd, B: PartialOrd, C: PartialOrd, D: PartialOrd, E: PartialOrd, F: PartialOrd> PartialOrd<Cell6<A, B, C, D, E, F>> for Cell6<A, B, C, D, E, F>This is supported on cell only.
impl<A: PartialOrd, B: PartialOrd, C: PartialOrd, D: PartialOrd, E: PartialOrd, F: PartialOrd> PartialOrd<Cell6<A, B, C, D, E, F>> for Cell6<A, B, C, D, E, F>This is supported on
cell only.This method returns an ordering between self and other values if one exists. Read more
This method tests less than (for self and other) and is used by the < operator. Read more
This method tests less than or equal to (for self and other) and is used by the <=
operator. Read more
This method tests greater than (for self and other) and is used by the > operator. Read more
impl<A: Copy, B: Copy, C: Copy, D: Copy, E: Copy, F: Copy> Copy for Cell6<A, B, C, D, E, F>This is supported on
cell only.impl<A: Eq, B: Eq, C: Eq, D: Eq, E: Eq, F: Eq> Eq for Cell6<A, B, C, D, E, F>This is supported on
cell only.impl<A, B, C, D, E, F> StructuralPartialEq for Cell6<A, B, C, D, E, F>This is supported on
cell only.Auto Trait Implementations
impl<A, B, C, D, E, F> RefUnwindSafe for Cell6<A, B, C, D, E, F> where
A: RefUnwindSafe,
B: RefUnwindSafe,
C: RefUnwindSafe,
D: RefUnwindSafe,
E: RefUnwindSafe,
F: RefUnwindSafe, impl<A, B, C, D, E, F> Send for Cell6<A, B, C, D, E, F> where
A: Send,
B: Send,
C: Send,
D: Send,
E: Send,
F: Send, impl<A, B, C, D, E, F> Sync for Cell6<A, B, C, D, E, F> where
A: Sync,
B: Sync,
C: Sync,
D: Sync,
E: Sync,
F: Sync, impl<A, B, C, D, E, F> Unpin for Cell6<A, B, C, D, E, F> where
A: Unpin,
B: Unpin,
C: Unpin,
D: Unpin,
E: Unpin,
F: Unpin, impl<A, B, C, D, E, F> UnwindSafe for Cell6<A, B, C, D, E, F> where
A: UnwindSafe,
B: UnwindSafe,
C: UnwindSafe,
D: UnwindSafe,
E: UnwindSafe,
F: UnwindSafe, Blanket Implementations
Mutably borrows from an owned value. Read more