Enum memtable_core::exts::prelude::Cell8 [−][src]
pub enum Cell8<A, B, C, D, E, F, G, H> {
A(A),
B(B),
C(C),
D(D),
E(E),
F(F),
G(G),
H(H),
}Variants
Implementations
This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.This is supported on
cell only.Trait Implementations
impl<'de, A, B, C, D, E, F, G, H> Deserialize<'de> for Cell8<A, B, C, D, E, F, G, H> where
A: Deserialize<'de>,
B: Deserialize<'de>,
C: Deserialize<'de>,
D: Deserialize<'de>,
E: Deserialize<'de>,
F: Deserialize<'de>,
G: Deserialize<'de>,
H: Deserialize<'de>, This is supported on cell only.
impl<'de, A, B, C, D, E, F, G, H> Deserialize<'de> for Cell8<A, B, C, D, E, F, G, H> where
A: Deserialize<'de>,
B: Deserialize<'de>,
C: Deserialize<'de>,
D: Deserialize<'de>,
E: Deserialize<'de>,
F: Deserialize<'de>,
G: Deserialize<'de>,
H: Deserialize<'de>, This is supported on
cell only.fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error> where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error> where
__D: Deserializer<'de>, Deserialize this value from the given Serde deserializer. Read more
impl<A: PartialOrd, B: PartialOrd, C: PartialOrd, D: PartialOrd, E: PartialOrd, F: PartialOrd, G: PartialOrd, H: PartialOrd> PartialOrd<Cell8<A, B, C, D, E, F, G, H>> for Cell8<A, B, C, D, E, F, G, H>This is supported on cell only.
impl<A: PartialOrd, B: PartialOrd, C: PartialOrd, D: PartialOrd, E: PartialOrd, F: PartialOrd, G: PartialOrd, H: PartialOrd> PartialOrd<Cell8<A, B, C, D, E, F, G, H>> for Cell8<A, B, C, D, E, F, G, H>This is supported on
cell only.This method returns an ordering between self and other values if one exists. Read more
This method tests less than (for self and other) and is used by the < operator. Read more
This method tests less than or equal to (for self and other) and is used by the <=
operator. Read more
This method tests greater than (for self and other) and is used by the > operator. Read more
impl<A: Copy, B: Copy, C: Copy, D: Copy, E: Copy, F: Copy, G: Copy, H: Copy> Copy for Cell8<A, B, C, D, E, F, G, H>This is supported on
cell only.impl<A: Eq, B: Eq, C: Eq, D: Eq, E: Eq, F: Eq, G: Eq, H: Eq> Eq for Cell8<A, B, C, D, E, F, G, H>This is supported on
cell only.impl<A, B, C, D, E, F, G, H> StructuralEq for Cell8<A, B, C, D, E, F, G, H>This is supported on
cell only.impl<A, B, C, D, E, F, G, H> StructuralPartialEq for Cell8<A, B, C, D, E, F, G, H>This is supported on
cell only.Auto Trait Implementations
impl<A, B, C, D, E, F, G, H> RefUnwindSafe for Cell8<A, B, C, D, E, F, G, H> where
A: RefUnwindSafe,
B: RefUnwindSafe,
C: RefUnwindSafe,
D: RefUnwindSafe,
E: RefUnwindSafe,
F: RefUnwindSafe,
G: RefUnwindSafe,
H: RefUnwindSafe, impl<A, B, C, D, E, F, G, H> Send for Cell8<A, B, C, D, E, F, G, H> where
A: Send,
B: Send,
C: Send,
D: Send,
E: Send,
F: Send,
G: Send,
H: Send, impl<A, B, C, D, E, F, G, H> Sync for Cell8<A, B, C, D, E, F, G, H> where
A: Sync,
B: Sync,
C: Sync,
D: Sync,
E: Sync,
F: Sync,
G: Sync,
H: Sync, impl<A, B, C, D, E, F, G, H> Unpin for Cell8<A, B, C, D, E, F, G, H> where
A: Unpin,
B: Unpin,
C: Unpin,
D: Unpin,
E: Unpin,
F: Unpin,
G: Unpin,
H: Unpin, impl<A, B, C, D, E, F, G, H> UnwindSafe for Cell8<A, B, C, D, E, F, G, H> where
A: UnwindSafe,
B: UnwindSafe,
C: UnwindSafe,
D: UnwindSafe,
E: UnwindSafe,
F: UnwindSafe,
G: UnwindSafe,
H: UnwindSafe, Blanket Implementations
Mutably borrows from an owned value. Read more