Struct memtable_core::Position [−][src]
Represents the position of a cell in a table
Fields
row: usizeRepresents the row number of a cell starting from 0
col: usizeRepresents the coumn number of a cell starting from 0
Implementations